==> java-sdk-9.0.1-sources.jar: com/geotab/api/DataStore.java <==
package com.geotab.api;

import static com.geotab.api.Api.entity;

import com.geotab.api.Api.EntityDescriptor;
import com.geotab.model.search.AnnotationLogSearch;
import com.geotab.model.search.AuditSearch;
import com.geotab.model.search.ControllerSearch;
import com.geotab.model.search.CustomDataSearch;
import com.geotab.model.search.DVIRLogSearch;
import com.geotab.model.search.DebugDataSearch;
import com.geotab.model.search.DeviceSearch;
import com.geotab.model.search.DeviceStatusInfoSearch;
import com.geotab.model.search.DiagnosticSearch;
import com.geotab.model.search.DistributionListSearch;
import com.geotab.model.search.DriverChangeSearch;
import com.geotab.model.search.DutyStatusAvailabilitySearch;
import com.geotab.model.search.DutyStatusLogSearch;
import com.geotab.model.search.DutyStatusViolationSearch;
import com.geotab.model.search.ExceptionEventSearch;
import com.geotab.model.search.FaultDataSearch;
import com.geotab.model.search.FuelTaxDetailSearch;
import com.geotab.model.search.FuelTransactionSearch;
import com.geotab.model.search.FuelUsedSearch;
import com.geotab.model.search.GroupSearch;
import com.geotab.model.search.IoxAddOnSearch;
import com.geotab.model.search.LogRecordSearch;
import com.geotab.model.search.MediaFileSearch;
import com.geotab.model.search.PropertySearch;
import com.geotab.model.search.PropertySetSearch;
import com.geotab.model.search.RecipientSearch;
import com.geotab.model.search.ReportTemplateSearch;
import com.geotab.model.search.RouteSearch;
import com.geotab.model.search.RuleSearch;
import com.geotab.model.search.Search;
import com.geotab.model.search.ShipmentLogSearch;
import com.geotab.model.search.StatusDataSearch;
import com.geotab.model.search.TextMessageSearch;
import com.geotab.model.search.TrailerAttachmentSearch;
import com.geotab.model.search.TrailerSearch;
import com.geotab.model.search.TripSearch;
import com.geotab.model.search.UserSearch;
import com.geotab.model.search.WifiHotspotSearch;
import com.geotab.model.search.WorkHolidaySearch;
import com.geotab.model.search.WorkTimeSearch;
import com.geotab.model.search.ZoneSearch;

/**
 * List of DataStore entities.
 *
 * <p><b>WARNING:</b> Experimental API.
 */
public interface DataStore {
  //@formatter:off
  EntityDescriptor<com.geotab.model.entity.audit.Audit, AuditSearch> AuditEntity = entity(com.geotab.model.entity.audit.Audit.class);
  EntityDescriptor<com.geotab.model.entity.certificate.Certificate, Search> CertificateEntity = entity(com.geotab.model.entity.certificate.Certificate.class);
  EntityDescriptor<com.geotab.model.entity.condition.Condition, Search> ConditionEntity = entity(com.geotab.model.entity.condition.Condition.class);
  EntityDescriptor<com.geotab.model.entity.controller.Controller, ControllerSearch> ControllerEntity = entity(com.geotab.model.entity.controller.Controller.class);
  EntityDescriptor<com.geotab.model.entity.customdata.CustomData, CustomDataSearch> CustomDataEntity = entity(com.geotab.model.entity.customdata.CustomData.class);
  EntityDescriptor<com.geotab.model.entity.customproperty.Property, PropertySearch> PropertyEntity = entity(com.geotab.model.entity.customproperty.Property.class);
  EntityDescriptor<com.geotab.model.entity.customproperty.PropertySet, PropertySetSearch> PropertySetEntity = entity(com.geotab.model.entity.customproperty.PropertySet.class);
  EntityDescriptor<com.geotab.model.entity.customproperty.PropertyValue, Search> PropertyValueEntity = entity(com.geotab.model.entity.customproperty.PropertyValue.class);
  EntityDescriptor<com.geotab.model.entity.debugdata.DebugData, DebugDataSearch> DebugDataEntity = entity(com.geotab.model.entity.debugdata.DebugData.class);
  EntityDescriptor<com.geotab.model.entity.device.Device, DeviceSearch> DeviceEntity = entity(com.geotab.model.entity.device.Device.class);
  EntityDescriptor<com.geotab.model.entity.devicestatusinfo.DeviceStatusInfo, DeviceStatusInfoSearch> DeviceStatusInfoEntity = entity(com.geotab.model.entity.devicestatusinfo.DeviceStatusInfo.class);
  EntityDescriptor<com.geotab.model.entity.diagnostic.Diagnostic, DiagnosticSearch> BasicDiagnosticEntity = entity(com.geotab.model.entity.diagnostic.Diagnostic.class);
  EntityDescriptor<com.geotab.model.entity.distributionlist.DistributionList, DistributionListSearch> DistributionListEntity = entity(com.geotab.model.entity.distributionlist.DistributionList.class);
  EntityDescriptor<com.geotab.model.entity.driverchange.DriverChange, DriverChangeSearch> DriverChangeEntity = entity(com.geotab.model.entity.driverchange.DriverChange.class);
  EntityDescriptor<com.geotab.model.entity.dutystatus.AnnotationLog, AnnotationLogSearch> AnnotationLogEntity = entity(com.geotab.model.entity.dutystatus.AnnotationLog.class);
  EntityDescriptor<com.geotab.model.entity.dutystatus.DutyStatusAvailability, DutyStatusAvailabilitySearch> DutyStatusAvailabilityEntity = entity(com.geotab.model.entity.dutystatus.DutyStatusAvailability.class);
  EntityDescriptor<com.geotab.model.entity.dutystatus.DutyStatusLog, DutyStatusLogSearch> DutyStatusLogEntity = entity(com.geotab.model.entity.dutystatus.DutyStatusLog.class);
  EntityDescriptor<com.geotab.model.entity.dutystatus.DutyStatusViolation, DutyStatusViolationSearch> DutyStatusViolationEntity = entity(com.geotab.model.entity.dutystatus.DutyStatusViolation.class);
  EntityDescriptor<com.geotab.model.entity.dvirlog.DVIRDefect, Search> DVIRDefectEntity = entity(com.geotab.model.entity.dvirlog.DVIRDefect.class);
  EntityDescriptor<com.geotab.model.entity.dvirlog.DVIRLog, DVIRLogSearch> DVIRLogEntity = entity(com.geotab.model.entity.dvirlog.DVIRLog.class);
  EntityDescriptor<com.geotab.model.entity.dvirlog.DefectRemark, Search> DefectRemarkEntity = entity(com.geotab.model.entity.dvirlog.DefectRemark.class);
  EntityDescriptor<com.geotab.model.entity.enginetype.EngineType, Search> EngineTypeEntity = entity(com.geotab.model.entity.enginetype.EngineType.class);
  EntityDescriptor<com.geotab.model.entity.exceptionevent.ExceptionEvent, ExceptionEventSearch> ExceptionEventEntity = entity(com.geotab.model.entity.exceptionevent.ExceptionEvent.class);
  EntityDescriptor<com.geotab.model.entity.exceptionevent.state.ExceptionEventState, Search> ExceptionEventStateEntity = entity(com.geotab.model.entity.exceptionevent.state.ExceptionEventState.class);
  EntityDescriptor<com.geotab.model.entity.failuremode.FailureMode, Search> FailureModeEntity = entity(com.geotab.model.entity.failuremode.FailureMode.class);
  EntityDescriptor<com.geotab.model.entity.faultdata.FaultData, FaultDataSearch> FaultDataEntity = entity(com.geotab.model.entity.faultdata.FaultData.class);
  EntityDescriptor<com.geotab.model.entity.faultdata.FaultStatus, Search> FaultStatusEntity = entity(com.geotab.model.entity.faultdata.FaultStatus.class);
  EntityDescriptor<com.geotab.model.entity.file.MediaFile, MediaFileSearch> MediaFileEntity = entity(com.geotab.model.entity.file.MediaFile.class);
  EntityDescriptor<com.geotab.model.entity.file.Tag, Search> TagEntity = entity(com.geotab.model.entity.file.Tag.class);
  EntityDescriptor<com.geotab.model.entity.flashcode.FlashCode, Search> FlashCodeEntity = entity(com.geotab.model.entity.flashcode.FlashCode.class);
  EntityDescriptor<com.geotab.model.entity.fuel.FuelEvent, Search> FuelEventEntity = entity(com.geotab.model.entity.fuel.FuelEvent.class);
  EntityDescriptor<com.geotab.model.entity.fuel.FuelTaxDetail, FuelTaxDetailSearch> FuelTaxDetailEntity = entity(com.geotab.model.entity.fuel.FuelTaxDetail.class);
  EntityDescriptor<com.geotab.model.entity.fuel.FuelTransaction, FuelTransactionSearch> FuelTransactionEntity = entity(com.geotab.model.entity.fuel.FuelTransaction.class);
  EntityDescriptor<com.geotab.model.entity.fuel.FuelUsed, FuelUsedSearch> FuelUsedEntity = entity(com.geotab.model.entity.fuel.FuelUsed.class);
  EntityDescriptor<com.geotab.model.entity.group.Group, GroupSearch> GroupEntity = entity(com.geotab.model.entity.group.Group.class);
  EntityDescriptor<com.geotab.model.entity.hos.HosRuleSetNew, Search> HosRuleSetNewEntity = entity(com.geotab.model.entity.hos.HosRuleSetNew.class);
  EntityDescriptor<com.geotab.model.entity.hos.UserHosRuleSet, Search> UserHosRuleSetEntity = entity(com.geotab.model.entity.hos.UserHosRuleSet.class);
  EntityDescriptor<com.geotab.model.entity.ioxaddon.IoxAddOn, IoxAddOnSearch> IoxAddOnEntity = entity(com.geotab.model.entity.ioxaddon.IoxAddOn.class);
  EntityDescriptor<com.geotab.model.entity.logrecord.LogRecord, LogRecordSearch> LogRecordEntity = entity(com.geotab.model.entity.logrecord.LogRecord.class);
  EntityDescriptor<com.geotab.model.entity.notification.NotificationBinaryFile, Search> NotificationBinaryFileEntity = entity(com.geotab.model.entity.notification.NotificationBinaryFile.class);
  EntityDescriptor<com.geotab.model.entity.parametergroup.ParameterGroup, Search> ParameterGroupEntity = entity(com.geotab.model.entity.parametergroup.ParameterGroup.class);
  EntityDescriptor<com.geotab.model.entity.recipient.Recipient, RecipientSearch> RecipientEntity = entity(com.geotab.model.entity.recipient.Recipient.class);
  EntityDescriptor<com.geotab.model.entity.reporttemplate.ReportTemplate, ReportTemplateSearch> ReportTemplateEntity = entity(com.geotab.model.entity.reporttemplate.ReportTemplate.class);
  EntityDescriptor<com.geotab.model.entity.route.Route, RouteSearch> RouteEntity = entity(com.geotab.model.entity.route.Route.class);
  EntityDescriptor<com.geotab.model.entity.route.RoutePlanItem, Search> RoutePlanItemEntity = entity(com.geotab.model.entity.route.RoutePlanItem.class);
  EntityDescriptor<com.geotab.model.entity.rule.Rule, RuleSearch> RuleEntity = entity(com.geotab.model.entity.rule.Rule.class);
  EntityDescriptor<com.geotab.model.entity.security.SecurityId, Search> SecurityIdEntity = entity(com.geotab.model.entity.security.SecurityId.class);
  EntityDescriptor<com.geotab.model.entity.shipmentlog.ShipmentLog, ShipmentLogSearch> ShipmentLogEntity = entity(com.geotab.model.entity.shipmentlog.ShipmentLog.class);
  EntityDescriptor<com.geotab.model.entity.source.Source, Search> SourceEntity = entity(com.geotab.model.entity.source.Source.class);
  EntityDescriptor<com.geotab.model.entity.statusdata.StatusData, StatusDataSearch> StatusDataEntity = entity(com.geotab.model.entity.statusdata.StatusData.class);
  EntityDescriptor<com.geotab.model.entity.textmessage.TextMessage, TextMessageSearch> TextMessageEntity = entity(com.geotab.model.entity.textmessage.TextMessage.class);
  EntityDescriptor<com.geotab.model.entity.trailer.Trailer, TrailerSearch> TrailerEntity = entity(com.geotab.model.entity.trailer.Trailer.class);
  EntityDescriptor<com.geotab.model.entity.trailer.TrailerAttachment, TrailerAttachmentSearch> TrailerAttachmentEntity = entity(com.geotab.model.entity.trailer.TrailerAttachment.class);
  EntityDescriptor<com.geotab.model.entity.trip.Trip, TripSearch> TripEntity = entity(com.geotab.model.entity.trip.Trip.class);
  EntityDescriptor<com.geotab.model.entity.unitofmeasure.UnitOfMeasure, Search> UnitOfMeasureEntity = entity(com.geotab.model.entity.unitofmeasure.UnitOfMeasure.class);
  EntityDescriptor<com.geotab.model.entity.user.User, UserSearch> UserEntity = entity(com.geotab.model.entity.user.User.class);
  EntityDescriptor<com.geotab.model.entity.wifi.WifiHotspot, WifiHotspotSearch> WifiHotspotEntity = entity(com.geotab.model.entity.wifi.WifiHotspot.class);
  EntityDescriptor<com.geotab.model.entity.workholiday.WorkHoliday, WorkHolidaySearch> WorkHolidayEntity = entity(com.geotab.model.entity.workholiday.WorkHoliday.class);
  EntityDescriptor<com.geotab.model.entity.worktime.WorkTime, WorkTimeSearch> WorkTimeEntity = entity(com.geotab.model.entity.worktime.WorkTime.class);
  EntityDescriptor<com.geotab.model.entity.zone.Zone, ZoneSearch> ZoneEntity = entity(com.geotab.model.entity.zone.Zone.class);
  EntityDescriptor<com.geotab.model.entity.zone.type.ZoneType, Search> ZoneTypeEntity = entity(com.geotab.model.entity.zone.type.ZoneType.class);
  //@formatter:on
}

==> java-sdk-9.0.3-sources.jar: com/geotab/api/DataStore.java <==
package com.geotab.api;

import static com.geotab.api.Api.entity;

import com.geotab.api.Api.EntityDescriptor;
import com.geotab.model.search.AddInSearch;
import com.geotab.model.search.AnnotationLogSearch;
import com.geotab.model.search.AuditSearch;
import com.geotab.model.search.ChargeEventSearch;
import com.geotab.model.search.ControllerSearch;
import com.geotab.model.search.CustomDataSearch;
import com.geotab.model.search.DVIRLogSearch;
import com.geotab.model.search.DebugDataSearch;
import com.geotab.model.search.DeviceSearch;
import com.geotab.model.search.DeviceStatusInfoSearch;
import com.geotab.model.search.DiagnosticSearch;
import com.geotab.model.search.DistributionListSearch;
import com.geotab.model.search.DriverChangeSearch;
import com.geotab.model.search.DutyStatusAvailabilitySearch;
import com.geotab.model.search.DutyStatusLogSearch;
import com.geotab.model.search.DutyStatusViolationSearch;
import com.geotab.model.search.ExceptionEventSearch;
import com.geotab.model.search.FaultDataSearch;
import com.geotab.model.search.FuelTaxDetailSearch;
import com.geotab.model.search.FuelTransactionSearch;
import com.geotab.model.search.FuelUsedSearch;
import com.geotab.model.search.GroupSearch;
import com.geotab.model.search.IoxAddOnSearch;
import com.geotab.model.search.IoxAddOnStatusSearch;
import com.geotab.model.search.LogRecordSearch;
import com.geotab.model.search.MediaFileSearch;
import com.geotab.model.search.PropertySearch;
import com.geotab.model.search.PropertySetSearch;
import com.geotab.model.search.RecipientSearch;
import com.geotab.model.search.ReportTemplateSearch;
import com.geotab.model.search.RouteSearch;
import com.geotab.model.search.RuleSearch;
import com.geotab.model.search.Search;
import com.geotab.model.search.ShipmentLogSearch;
import com.geotab.model.search.StatusDataSearch;
import com.geotab.model.search.TachographCompanyCardSearch;
import com.geotab.model.search.TachographDataFileSearch;
import com.geotab.model.search.TextMessageSearch;
import com.geotab.model.search.TrailerAttachmentSearch;
import com.geotab.model.search.TrailerSearch;
import com.geotab.model.search.TripSearch;
import com.geotab.model.search.UserSearch;
import com.geotab.model.search.WifiHotspotSearch;
import com.geotab.model.search.WorkHolidaySearch;
import com.geotab.model.search.WorkTimeSearch;
import com.geotab.model.search.ZoneSearch;

/**
 * List of DataStore entities.
 *
 * <p><b>WARNING:</b> Experimental API.
 */
public interface DataStore {
  //@formatter:off
  EntityDescriptor<com.geotab.model.entity.addins.AddIn, AddInSearch> AddInEntity = entity(com.geotab.model.entity.addins.AddIn.class);
  EntityDescriptor<com.geotab.model.entity.addins.AddInData, Search> AddInDataEntity = entity(com.geotab.model.entity.addins.AddInData.class);
  EntityDescriptor<com.geotab.model.entity.audit.Audit, AuditSearch> AuditEntity = entity(com.geotab.model.entity.audit.Audit.class);
  EntityDescriptor<com.geotab.model.entity.certificate.Certificate, Search> CertificateEntity = entity(com.geotab.model.entity.certificate.Certificate.class);
  EntityDescriptor<com.geotab.model.entity.charging.ChargeEvent, ChargeEventSearch> ChargeEventEntity = entity(com.geotab.model.entity.charging.ChargeEvent.class);
  EntityDescriptor<com.geotab.model.entity.condition.Condition, Search> ConditionEntity = entity(com.geotab.model.entity.condition.Condition.class);
  EntityDescriptor<com.geotab.model.entity.controller.Controller, ControllerSearch> ControllerEntity = entity(com.geotab.model.entity.controller.Controller.class);
  EntityDescriptor<com.geotab.model.entity.customdata.CustomData, CustomDataSearch> CustomDataEntity = entity(com.geotab.model.entity.customdata.CustomData.class);
  EntityDescriptor<com.geotab.model.entity.customproperty.Property, PropertySearch> PropertyEntity = entity(com.geotab.model.entity.customproperty.Property.class);
  EntityDescriptor<com.geotab.model.entity.customproperty.PropertySet, PropertySetSearch> PropertySetEntity = entity(com.geotab.model.entity.customproperty.PropertySet.class);
  EntityDescriptor<com.geotab.model.entity.customproperty.PropertyValue, Search> PropertyValueEntity = entity(com.geotab.model.entity.customproperty.PropertyValue.class);
  EntityDescriptor<com.geotab.model.entity.debugdata.DebugData, DebugDataSearch> DebugDataEntity = entity(com.geotab.model.entity.debugdata.DebugData.class);
  EntityDescriptor<com.geotab.model.entity.device.Device, DeviceSearch> DeviceEntity = entity(com.geotab.model.entity.device.Device.class);
  EntityDescriptor<com.geotab.model.entity.devicestatusinfo.DeviceStatusInfo, DeviceStatusInfoSearch> DeviceStatusInfoEntity = entity(com.geotab.model.entity.devicestatusinfo.DeviceStatusInfo.class);
  EntityDescriptor<com.geotab.model.entity.diagnostic.Diagnostic, DiagnosticSearch> BasicDiagnosticEntity = entity(com.geotab.model.entity.diagnostic.Diagnostic.class);
  EntityDescriptor<com.geotab.model.entity.distributionlist.DistributionList, DistributionListSearch> DistributionListEntity = entity(com.geotab.model.entity.distributionlist.DistributionList.class);
  EntityDescriptor<com.geotab.model.entity.driverchange.DriverChange, DriverChangeSearch> DriverChangeEntity = entity(com.geotab.model.entity.driverchange.DriverChange.class);
  EntityDescriptor<com.geotab.model.entity.dutystatus.AnnotationLog, AnnotationLogSearch> AnnotationLogEntity = entity(com.geotab.model.entity.dutystatus.AnnotationLog.class);
  EntityDescriptor<com.geotab.model.entity.dutystatus.DutyStatusAvailability, DutyStatusAvailabilitySearch> DutyStatusAvailabilityEntity = entity(com.geotab.model.entity.dutystatus.DutyStatusAvailability.class);
  EntityDescriptor<com.geotab.model.entity.dutystatus.DutyStatusLog, DutyStatusLogSearch> DutyStatusLogEntity = entity(com.geotab.model.entity.dutystatus.DutyStatusLog.class);
  EntityDescriptor<com.geotab.model.entity.dutystatus.DutyStatusViolation, DutyStatusViolationSearch> DutyStatusViolationEntity = entity(com.geotab.model.entity.dutystatus.DutyStatusViolation.class);
  EntityDescriptor<com.geotab.model.entity.dvirlog.DVIRDefect, Search> DVIRDefectEntity = entity(com.geotab.model.entity.dvirlog.DVIRDefect.class);
  EntityDescriptor<com.geotab.model.entity.dvirlog.DVIRLog, DVIRLogSearch> DVIRLogEntity = entity(com.geotab.model.entity.dvirlog.DVIRLog.class);
  EntityDescriptor<com.geotab.model.entity.dvirlog.DefectRemark, Search> DefectRemarkEntity = entity(com.geotab.model.entity.dvirlog.DefectRemark.class);
  EntityDescriptor<com.geotab.model.entity.enginetype.EngineType, Search> EngineTypeEntity = entity(com.geotab.model.entity.enginetype.EngineType.class);
  EntityDescriptor<com.geotab.model.entity.exceptionevent.ExceptionEvent, ExceptionEventSearch> ExceptionEventEntity = entity(com.geotab.model.entity.exceptionevent.ExceptionEvent.class);
  EntityDescriptor<com.geotab.model.entity.exceptionevent.state.ExceptionEventState, Search> ExceptionEventStateEntity = entity(com.geotab.model.entity.exceptionevent.state.ExceptionEventState.class);
  EntityDescriptor<com.geotab.model.entity.failuremode.FailureMode, Search> FailureModeEntity = entity(com.geotab.model.entity.failuremode.FailureMode.class);
  EntityDescriptor<com.geotab.model.entity.faultdata.FaultData, FaultDataSearch> FaultDataEntity = entity(com.geotab.model.entity.faultdata.FaultData.class);
  EntityDescriptor<com.geotab.model.entity.faultdata.FaultStatus, Search> FaultStatusEntity = entity(com.geotab.model.entity.faultdata.FaultStatus.class);
  EntityDescriptor<com.geotab.model.entity.file.MediaFile, MediaFileSearch> MediaFileEntity = entity(com.geotab.model.entity.file.MediaFile.class);
  EntityDescriptor<com.geotab.model.entity.file.Tag, Search> TagEntity = entity(com.geotab.model.entity.file.Tag.class);
  EntityDescriptor<com.geotab.model.entity.flashcode.FlashCode, Search> FlashCodeEntity = entity(com.geotab.model.entity.flashcode.FlashCode.class);
  EntityDescriptor<com.geotab.model.entity.fuel.FuelEvent, Search> FuelEventEntity = entity(com.geotab.model.entity.fuel.FuelEvent.class);
  EntityDescriptor<com.geotab.model.entity.fuel.FuelTaxDetail, FuelTaxDetailSearch> FuelTaxDetailEntity = entity(com.geotab.model.entity.fuel.FuelTaxDetail.class);
  EntityDescriptor<com.geotab.model.entity.fuel.FuelTransaction, FuelTransactionSearch> FuelTransactionEntity = entity(com.geotab.model.entity.fuel.FuelTransaction.class);
  EntityDescriptor<com.geotab.model.entity.fuel.FuelUsed, FuelUsedSearch> FuelUsedEntity = entity(com.geotab.model.entity.fuel.FuelUsed.class);
  EntityDescriptor<com.geotab.model.entity.group.Group, GroupSearch> GroupEntity = entity(com.geotab.model.entity.group.Group.class);
  EntityDescriptor<com.geotab.model.entity.hos.HosRuleSetNew, Search> HosRuleSetNewEntity = entity(com.geotab.model.entity.hos.HosRuleSetNew.class);
  EntityDescriptor<com.geotab.model.entity.hos.UserHosRuleSet, Search> UserHosRuleSetEntity = entity(com.geotab.model.entity.hos.UserHosRuleSet.class);
  EntityDescriptor<com.geotab.model.entity.ioxaddon.IoxAddOn, IoxAddOnSearch> IoxAddOnEntity = entity(com.geotab.model.entity.ioxaddon.IoxAddOn.class);
  EntityDescriptor<com.geotab.model.entity.ioxaddonstatus.IoxAddOnStatus, IoxAddOnStatusSearch> IoxAddOnStatusEntity = entity(com.geotab.model.entity.ioxaddonstatus.IoxAddOnStatus.class);
  EntityDescriptor<com.geotab.model.entity.logrecord.LogRecord, LogRecordSearch> LogRecordEntity = entity(com.geotab.model.entity.logrecord.LogRecord.class);
  EntityDescriptor<com.geotab.model.entity.notification.NotificationBinaryFile, Search> NotificationBinaryFileEntity = entity(com.geotab.model.entity.notification.NotificationBinaryFile.class);
  EntityDescriptor<com.geotab.model.entity.parametergroup.ParameterGroup, Search> ParameterGroupEntity = entity(com.geotab.model.entity.parametergroup.ParameterGroup.class);
  EntityDescriptor<com.geotab.model.entity.recipient.Recipient, RecipientSearch> RecipientEntity = entity(com.geotab.model.entity.recipient.Recipient.class);
  EntityDescriptor<com.geotab.model.entity.reporttemplate.ReportTemplate, ReportTemplateSearch> ReportTemplateEntity = entity(com.geotab.model.entity.reporttemplate.ReportTemplate.class);
  EntityDescriptor<com.geotab.model.entity.route.Route, RouteSearch> RouteEntity = entity(com.geotab.model.entity.route.Route.class);
  EntityDescriptor<com.geotab.model.entity.route.RoutePlanItem, Search> RoutePlanItemEntity = entity(com.geotab.model.entity.route.RoutePlanItem.class);
  EntityDescriptor<com.geotab.model.entity.rule.Rule, RuleSearch> RuleEntity = entity(com.geotab.model.entity.rule.Rule.class);
  EntityDescriptor<com.geotab.model.entity.security.SecurityId, Search> SecurityIdEntity = entity(com.geotab.model.entity.security.SecurityId.class);
  EntityDescriptor<com.geotab.model.entity.shipmentlog.ShipmentLog, ShipmentLogSearch> ShipmentLogEntity = entity(com.geotab.model.entity.shipmentlog.ShipmentLog.class);
  EntityDescriptor<com.geotab.model.entity.source.Source, Search> SourceEntity = entity(com.geotab.model.entity.source.Source.class);
  EntityDescriptor<com.geotab.model.entity.statusdata.StatusData, StatusDataSearch> StatusDataEntity = entity(com.geotab.model.entity.statusdata.StatusData.class);
  EntityDescriptor<com.geotab.model.entity.tachograph.TachographData, Search> TachographDataEntity = entity(com.geotab.model.entity.tachograph.TachographData.class);
  EntityDescriptor<com.geotab.model.entity.tachograph.companycards.TachographCompanyCard, TachographCompanyCardSearch> TachographCompanyCardEntity = entity(com.geotab.model.entity.tachograph.companycards.TachographCompanyCard.class);
  EntityDescriptor<com.geotab.model.entity.tachograph.files.TachographDataFile, TachographDataFileSearch> TachographDataFileEntity = entity(com.geotab.model.entity.tachograph.files.TachographDataFile.class);
  EntityDescriptor<com.geotab.model.entity.textmessage.TextMessage, TextMessageSearch> TextMessageEntity = entity(com.geotab.model.entity.textmessage.TextMessage.class);
  EntityDescriptor<com.geotab.model.entity.trailer.Trailer, TrailerSearch> TrailerEntity = entity(com.geotab.model.entity.trailer.Trailer.class);
  EntityDescriptor<com.geotab.model.entity.trailer.TrailerAttachment, TrailerAttachmentSearch> TrailerAttachmentEntity = entity(com.geotab.model.entity.trailer.TrailerAttachment.class);
  EntityDescriptor<com.geotab.model.entity.trip.Trip, TripSearch> TripEntity = entity(com.geotab.model.entity.trip.Trip.class);
  EntityDescriptor<com.geotab.model.entity.unitofmeasure.UnitOfMeasure, Search> UnitOfMeasureEntity = entity(com.geotab.model.entity.unitofmeasure.UnitOfMeasure.class);
  EntityDescriptor<com.geotab.model.entity.user.User, UserSearch> UserEntity = entity(com.geotab.model.entity.user.User.class);
  EntityDescriptor<com.geotab.model.entity.wifi.WifiHotspot, WifiHotspotSearch> WifiHotspotEntity = entity(com.geotab.model.entity.wifi.WifiHotspot.class);
  EntityDescriptor<com.geotab.model.entity.workholiday.WorkHoliday, WorkHolidaySearch> WorkHolidayEntity = entity(com.geotab.model.entity.workholiday.WorkHoliday.class);
  EntityDescriptor<com.geotab.model.entity.worktime.WorkTime, WorkTimeSearch> WorkTimeEntity = entity(com.geotab.model.entity.worktime.WorkTime.class);
  EntityDescriptor<com.geotab.model.entity.zone.Zone, ZoneSearch> ZoneEntity = entity(com.geotab.model.entity.zone.Zone.class);
  EntityDescriptor<com.geotab.model.entity.zone.type.ZoneType, Search> ZoneTypeEntity = entity(com.geotab.model.entity.zone.type.ZoneType.class);
  //@formatter:on
}
